.. currentmodule:: bana

.. _extensions:

Extensions
==========

All the patches to apply to the Maya API are listed here and are named after
their destination class.


OpenMaya
--------

.. toctree::
   :maxdepth: 2

   MDagPath <openmaya_mdagpath>
   MFnBase <openmaya_mfnbase>
   MFnDagNode <openmaya_mfndagnode>
   MFnDependencyNode <openmaya_mfndependencynode>
   MFnTransform <openmaya_mfntransform>
   MGlobal <openmaya_mglobal>
   MMatrix <openmaya_mmatrix>
   MObject <openmaya_mobject>
   MPoint <openmaya_mpoint>
   MQuaternion <openmaya_mquaternion>
   MTransformationMatrix <openmaya_mtransformationmatrix>
   MVector <openmaya_mvector>
